==> sumo_1.15.0+dfsg.orig.tar.xz: sumo-1_15_0/tests/netedit/demandelements/personplan/stops/stop_edge/create/until/test.py <==
#!/usr/bin/env python
# Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
# Copyright (C) 2009-2022 German Aerospace Center (DLR) and others.
# This program and the accompanying materials are made available under the
# terms of the Eclipse Public License 2.0 which is available at
# https://www.eclipse.org/legal/epl-2.0/
# This Source Code may also be made available under the following Secondary
# Licenses when the conditions for such availability set forth in the Eclipse
# Public License 2.0 are satisfied: GNU General Public License, version 2
# or later which is available at
# https://www.gnu.org/licenses/old-licenses/gpl-2.0-standalone.html
# SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later

# @file    test.py
# @author  Pablo Alvarez Lopez
# @date    2019-07-16

# import common functions for netedit tests
import os
import sys

testRoot = os.path.join(os.environ.get('SUMO_HOME', '.'), 'tests')
neteditTestRoot = os.path.join(
    os.environ.get('TEXTTEST_HOME', testRoot), 'netedit')
sys.path.append(neteditTestRoot)
import neteditTestFunctions as netedit  # noqa

# Open netedit
neteditProcess, referencePosition = netedit.setupAndStart(neteditTestRoot, ['--gui-testing-debug-gl'])

# force save additionals
netedit.forceSaveAdditionals()

# go to demand mode
netedit.supermodeDemand()

# go to person mode
netedit.personMode()

# change person plan
netedit.changePersonPlan("walk: edge->edge", False)

# create route using two one
netedit.leftClick(referencePosition, 274, 400)
netedit.leftClick(referencePosition, 180, 65)

# press enter to create route
netedit.typeEnter()

# go to personStopEdge mode
netedit.personPlanMode()

# select person
netedit.leftClick(referencePosition, 92, 412)

# go to personStopEdge mode
netedit.changePersonPlanMode("stopPerson: edge")

# create personStopEdge
netedit.leftClick(referencePosition, 180, 65)

# set invalid person number
netedit.changeDefaultBoolValue(netedit.attrs.personStopEdge.create.untilEnable)

# create personStopEdge
netedit.leftClick(referencePosition, 200, 65)

# set invalid person number
netedit.changeDefaultValue(netedit.attrs.personStopEdge.create.until, "dummy")

# create personStopEdge
netedit.leftClick(referencePosition, 220, 65)

# set invalid person number
netedit.changeDefaultValue(netedit.attrs.personStopEdge.create.until, "-20")

# create personStopEdge
netedit.leftClick(referencePosition, 240, 65)

# set invalid person number
netedit.changeDefaultValue(netedit.attrs.personStopEdge.create.until, "30.2")

# create personStopEdge
netedit.leftClick(referencePosition, 260, 65)

# Check undo redo
netedit.undo(referencePosition, 3)
netedit.redo(referencePosition, 3)

# save routes
netedit.saveRoutes(referencePosition)

# save additionals
netedit.saveAdditionals(referencePosition)

# save network
netedit.saveNetwork(referencePosition)

# quit netedit
netedit.quit(neteditProcess)

==> sumo_1.18.0+dfsg.orig.tar.xz: sumo-1_18_0/tests/netedit/demandelements/personplan/stops/stop_edge/create/until/test.py <==
#!/usr/bin/env python
# Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.dev/sumo
# Copyright (C) 2009-2023 German Aerospace Center (DLR) and others.
# This program and the accompanying materials are made available under the
# terms of the Eclipse Public License 2.0 which is available at
# https://www.eclipse.org/legal/epl-2.0/
# This Source Code may also be made available under the following Secondary
# Licenses when the conditions for such availability set forth in the Eclipse
# Public License 2.0 are satisfied: GNU General Public License, version 2
# or later which is available at
# https://www.gnu.org/licenses/old-licenses/gpl-2.0-standalone.html
# SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later

# @file    test.py
# @author  Pablo Alvarez Lopez
# @date    2019-07-16

# import common functions for netedit tests
import os
import sys

testRoot = os.path.join(os.environ.get('SUMO_HOME', '.'), 'tests')
neteditTestRoot = os.path.join(
    os.environ.get('TEXTTEST_HOME', testRoot), 'netedit')
sys.path.append(neteditTestRoot)
import neteditTestFunctions as netedit  # noqa

# Open netedit
neteditProcess, referencePosition = netedit.setupAndStart(neteditTestRoot)

# go to demand mode
netedit.supermodeDemand()

# go to person mode
netedit.personMode()

# change person plan
netedit.changePersonPlan("walk: edge", False)

# create route using two one
netedit.leftClick(referencePosition, 274, 400)
netedit.leftClick(referencePosition, 180, 65)

# press enter to create route
netedit.typeEnter()

# go to personStopEdge mode
netedit.personPlanMode()

# select person
netedit.leftClick(referencePosition, 92, 412)

# go to personStopEdge mode
netedit.changePersonPlanMode("stopPerson: edge")

# create personStopEdge
netedit.leftClick(referencePosition, 180, 65)

# set invalid person number
netedit.changeDefaultBoolValue(netedit.attrs.personStopEdge.create.untilEnable)

# create personStopEdge
netedit.leftClick(referencePosition, 200, 65)

# set invalid person number
netedit.changeDefaultValue(netedit.attrs.personStopEdge.create.until, "dummy")

# create personStopEdge
netedit.leftClick(referencePosition, 220, 65)

# set invalid person number
netedit.changeDefaultValue(netedit.attrs.personStopEdge.create.until, "-20")

# create personStopEdge
netedit.leftClick(referencePosition, 240, 65)

# set invalid person number
netedit.changeDefaultValue(netedit.attrs.personStopEdge.create.until, "30.2")

# create personStopEdge
netedit.leftClick(referencePosition, 260, 65)

# Check undo redo
netedit.undo(referencePosition, 3)
netedit.redo(referencePosition, 3)

# save Netedit config
netedit.saveNeteditConfig(referencePosition)

# quit netedit
netedit.quit(neteditProcess)
